synapto-plugin-linux-host-audio 0.1.0-dev.1

Linux host audio capture and playback plugin for the Synapto framework
docs.rs failed to build synapto-plugin-linux-host-audio-0.1.0-dev.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.